@@ -82,8 +82,8 @@ template_g_ci <- function(dataname,
         ),
         env = list(
           fun = switch(stat,
-            mean = substitute(stat_mean_ci),
-            median = substitute(stat_median_ci)
+            mean = substitute(tern::stat_mean_ci),
+            median = substitute(tern::stat_median_ci)
           )
         )
       )
@@ -101,11 +101,11 @@ template_g_ci <- function(dataname,
         env = list(
           fun = switch(stat,
             mean = substitute(
-              expr = function(x) stat_mean_ci(x, conf_level = conf_level),
+              expr = function(x) tern::stat_mean_ci(x, conf_level = conf_level),
               env = list(conf_level = conf_level)
             ),
             median = substitute(
-              expr = function(x) stat_median_ci(x, conf_level = conf_level),
+              expr = function(x) tern::stat_median_ci(x, conf_level = conf_level),
               env = list(conf_level = conf_level)
             )
           )
@@ -361,9 +361,10 @@ ui_g_ci <- function(id, ...) {
     output = teal.widgets::plot_with_settings_ui(id = ns("myplot")),
     encoding = tags$div(
       ### Reporter
-      teal.reporter::simple_reporter_ui(ns("simple_reporter")),
+      teal.reporter::add_card_button_ui(ns("add_reporter"), label = "Add Report Card"),
+      tags$br(), tags$br(),
       ###
-      tags$label("Encodings", class = "text-primary"),
+      tags$label("Encodings", class = "text-primary"), tags$br(),
       teal.transform::datanames_input(args[c("x_var", "y_var", "color")]),
       teal.transform::data_extract_ui(
         id = ns("x_var"),
@@ -472,10 +473,10 @@ srv_g_ci <- function(id,
         )
       )
 
-      x_label <- column_annotation_label(data()[[attr(x, "dataname")]], x)
-      y_label <- column_annotation_label(data()[[attr(y, "dataname")]], y)
+      x_label <- teal.modules.clinical::column_annotation_label(data()[[attr(x, "dataname")]], x)
+      y_label <- teal.modules.clinical::column_annotation_label(data()[[attr(y, "dataname")]], y)
       color_label <- if (length(color)) {
-        column_annotation_label(data()[[attr(color, "dataname")]], color)
+        teal.modules.clinical::column_annotation_label(data()[[attr(color, "dataname")]], color)
       } else {
         NULL
       }
@@ -510,7 +511,7 @@ srv_g_ci <- function(id,
       id = "decorator",
       data = all_q,
       decorators = select_decorators(decorators, "plot"),
-      expr = print(plot)
+      expr = plot
     )
     # Outputs to render.
     plot_r <- reactive(decorated_plot_q()[["plot"]])
@@ -549,7 +550,7 @@ srv_g_ci <- function(id,
         card$append_src(source_code_r())
         card
       }
-      teal.reporter::simple_reporter_srv("simple_reporter", reporter = reporter, card_fun = card_fun)
+      teal.reporter::add_card_button_srv("add_reporter", reporter = reporter, card_fun = card_fun)
     }
     ###
   })
