@@ -52,13 +52,12 @@ template_adverse_events <- function(dataname = "ANL",
             aeterm, tox_grade, causality, outcome, action, time, decod
           ) %>%
           dplyr::arrange(dplyr::desc(tox_grade)) %>%
-          `colnames<-`(col_labels(dataname, fill = TRUE)[vars]) %>%
+          `colnames<-`(teal.data::col_labels(dataname, fill = TRUE)[vars]) %>%
           dplyr::mutate( # Exception for columns of type difftime that is not supported by as_listing
             dplyr::across(
               dplyr::where(~ inherits(., what = "difftime")), ~ as.double(., units = "auto")
             )
           )
-        table_output <- DT::datatable(table_data)
       },
       env = list(
         dataname = as.name(dataname),
@@ -183,7 +182,6 @@ template_adverse_events <- function(dataname = "ANL",
 #'
 #' This module generates the following objects, which can be modified in place using decorators::
 #' - `plot` (`ggplot`)
-#' - `table` (`datatables` - output of `DT::datatable()`)
 #'
 #' A Decorator is applied to the specific output using a named list of `teal_transform_module` objects.
 #' The name of this list corresponds to the name of the output to which the decorator is applied.
@@ -193,8 +191,7 @@ template_adverse_events <- function(dataname = "ANL",
 #' tm_g_pp_adverse_events(
 #'    ..., # arguments for module
 #'    decorators = list(
-#'      plot = teal_transform_module(...), # applied only to `plot` output
-#'      table = teal_transform_module(...) # applied only to `table` output
+#'      plot = teal_transform_module(...) # applied only to `plot` output
 #'    )
 #' )
 #' ```
@@ -310,7 +307,7 @@ tm_g_pp_adverse_events <- function(label,
   checkmate::assert_class(pre_output, classes = "shiny.tag", null.ok = TRUE)
   checkmate::assert_class(post_output, classes = "shiny.tag", null.ok = TRUE)
   checkmate::assert_class(ggplot2_args, "ggplot2_args")
-  assert_decorators(decorators, names = c("plot", "table"))
+  assert_decorators(decorators, names = "plot")
 
   args <- as.list(environment())
   data_extract_list <- list(
@@ -364,14 +361,18 @@ ui_g_adverse_events <- function(id, ...) {
     output = tags$div(
       htmlOutput(ns("title")),
       teal.widgets::get_dt_rows(ns("table"), ns("table_rows")),
-      DT::DTOutput(outputId = ns("table")),
+      tags$div(
+        style = "overflow: auto;",
+        DT::DTOutput(outputId = ns("table"))
+      ),
       teal.widgets::plot_with_settings_ui(id = ns("chart"))
     ),
     encoding = tags$div(
       ### Reporter
-      teal.reporter::simple_reporter_ui(ns("simple_reporter")),
+      teal.reporter::add_card_button_ui(ns("add_reporter"), label = "Add Report Card"),
+      tags$br(), tags$br(),
       ###
-      tags$label("Encodings", class = "text-primary"),
+      tags$label("Encodings", class = "text-primary"), tags$br(),
       teal.transform::datanames_input(ui_args[c(
         "aeterm", "tox_grade", "causality", "outcome",
         "action", "time", "decod"
@@ -428,11 +429,10 @@ ui_g_adverse_events <- function(id, ...) {
           is_single_dataset = is_single_dataset_value
         )
       ),
-      ui_decorate_teal_data(ns("d_table"), decorators = select_decorators(ui_args$decorators, "table")),
       ui_decorate_teal_data(ns("d_plot"), decorators = select_decorators(ui_args$decorators, "plot")),
-      teal.widgets::panel_item(
+      bslib::accordion_panel(
         title = "Plot settings",
-        collapsed = TRUE,
+        open = TRUE,
         teal.widgets::optionalSliderInputValMinMax(
           ns("font_size"),
           "Font Size",
@@ -590,35 +590,26 @@ srv_g_adverse_events <- function(id,
     # Allow for the table and plot qenv to be joined
     table_q <- reactive({
       req(all_q())
-      teal.code::eval_code(all_q(), "table <- table_output")
+      within(all_q(), {
+        table <- rtables::df_to_tt(table_data)
+        table
+      })
     })
     plot_q <- reactive({
       req(all_q())
-      teal.code::eval_code(all_q(), "plot <- plot_output")
+      within(all_q(), plot <- plot_output)
     })
 
-    decorated_all_q_table <- srv_decorate_teal_data(
-      "d_table",
-      data = table_q,
-      decorators = select_decorators(decorators, "table"),
-      expr = table
-    )
-
     decorated_all_q_plot <- srv_decorate_teal_data(
       "d_plot",
       data = plot_q,
       decorators = select_decorators(decorators, "plot"),
-      expr = print(plot)
+      expr = plot
     )
 
-    table_r <- reactive({
-      req(decorated_all_q_table())
-      teal.code::dev_suppress(decorated_all_q_table()[["table"]])
-    })
-
     plot_r <- reactive({
       req(iv_r()$is_valid(), decorated_all_q_plot())
-      decorated_all_q_plot()[["plot"]]
+      req(decorated_all_q_plot())[["plot"]]
     })
 
     pws <- teal.widgets::plot_with_settings_srv(
@@ -628,13 +619,22 @@ srv_g_adverse_events <- function(id,
       width = plot_width
     )
 
-    output$table <- DT::renderDataTable(
-      expr = table_r(),
-      options = list(pageLength = input$table_rows)
-    )
+    table_r <- reactive({
+      q <- req(table_q())
+
+      list(
+        html = DT::datatable(
+          data = q[["table_data"]],
+          options = list(pageLength = input$table_rows)
+        ),
+        report = q[["table"]]
+      )
+    })
+
+    output$table <- DT::renderDataTable(table_r()[["html"]])
 
     decorated_all_q <- reactive(
-      c(decorated_all_q_table(), decorated_all_q_plot())
+      c(table_q(), decorated_all_q_plot())
     )
 
     # Render R code
@@ -655,7 +655,7 @@ srv_g_adverse_events <- function(id,
           filter_panel_api = filter_panel_api
         )
         card$append_text("Table", "header3")
-        card$append_table(teal.code::dev_suppress(table_r()))
+        card$append_table(table_r()[["report"]])
         card$append_text("Plot", "header3")
         card$append_plot(plot_r(), dim = pws$dim())
         if (!comment == "") {
@@ -665,7 +665,7 @@ srv_g_adverse_events <- function(id,
         card$append_src(source_code_r())
         card
       }
-      teal.reporter::simple_reporter_srv("simple_reporter", reporter = reporter, card_fun = card_fun)
+      teal.reporter::add_card_button_srv("add_reporter", reporter = reporter, card_fun = card_fun)
     }
     ###
   })
