@@ -19,7 +19,7 @@ template_smq <- function(dataname,
                          total_label = default_total_label(),
                          sort_criteria = c("freq_desc", "alpha"),
                          drop_arm_levels = TRUE,
-                         na_level = default_na_str(),
+                         na_level = tern::default_na_str(),
                          smq_varlabel = "Standardized MedDRA Query",
                          baskets = c("SMQ01NAM", "SMQ02NAM", "CQ01NAM"),
                          id_var = "USUBJID",
@@ -77,7 +77,7 @@ template_smq <- function(dataname,
   data_list <- add_expr(
     data_list,
     substitute(
-      anl <- h_stack_by_baskets(
+      anl <- tern::h_stack_by_baskets(
         df = dataname,
         baskets = baskets,
         smq_varlabel = smq_varlabel,
@@ -106,7 +106,7 @@ template_smq <- function(dataname,
   data_list <- add_expr(
     data_list,
     substitute(
-      anl <- df_explicit_na(
+      anl <- tern::df_explicit_na(
         dataname,
         na_level = na_str
       ),
@@ -120,7 +120,7 @@ template_smq <- function(dataname,
   data_list <- add_expr(
     data_list,
     substitute(
-      parentname <- df_explicit_na(
+      parentname <- tern::df_explicit_na(
         parentname,
         na_level = na_str
       ),
@@ -156,7 +156,7 @@ template_smq <- function(dataname,
       layout_list,
       if (drop_arm_levels) {
         substitute(
-          expr = rtables::split_cols_by(var = nested_col, split_fun = drop_split_levels),
+          expr = rtables::split_cols_by(var = nested_col, split_fun = rtables::drop_split_levels),
           env = list(nested_col = arm_var[[2]])
         )
       } else {
@@ -181,7 +181,7 @@ template_smq <- function(dataname,
   layout_list <- add_expr(
     layout_list,
     substitute(
-      expr = summarize_num_patients(
+      expr = tern::summarize_num_patients(
         var = id_var,
         .stats = c("unique"),
         .labels = c(
@@ -208,7 +208,7 @@ template_smq <- function(dataname,
         "SMQ",
         child_labels = "visible",
         nested = FALSE,
-        split_fun = trim_levels_in_group(llt, drop_outlevs = FALSE),
+        split_fun = rtables::trim_levels_in_group(llt, drop_outlevs = FALSE),
         indent_mod = -1L,
         label_pos = "topleft",
         split_label = split_label
@@ -223,7 +223,7 @@ template_smq <- function(dataname,
   layout_list <- add_expr(
     layout_list,
     substitute(
-      expr = summarize_num_patients(
+      expr = tern::summarize_num_patients(
         var = id_var,
         .stats = c("unique", "nonunique"),
         .labels = c(
@@ -240,7 +240,7 @@ template_smq <- function(dataname,
   layout_list <- add_expr(
     layout_list,
     substitute(
-      expr = count_occurrences(vars = llt, drop = FALSE),
+      expr = tern::count_occurrences(vars = llt, drop = FALSE),
       env = list(
         llt = llt
       )
@@ -250,7 +250,7 @@ template_smq <- function(dataname,
   layout_list <- add_expr(
     layout_list,
     substitute(
-      expr = append_varlabels(dataname, llt, indent = 1L),
+      expr = tern::append_varlabels(dataname, llt, indent = 1L),
       env = list(
         dataname = as.name("anl"),
         llt = llt
@@ -274,8 +274,8 @@ template_smq <- function(dataname,
     y$sort <- substitute(
       expr = {
         sorted_result <- result %>%
-          sort_at_path(path = c("SMQ"), scorefun = cont_n_allcols) %>%
-          sort_at_path(path = c("SMQ", "*", llt), scorefun = score_occurrences, na.pos = "last")
+          rtables::sort_at_path(path = c("SMQ"), scorefun = cont_n_allcols) %>%
+          rtables::sort_at_path(path = c("SMQ", "*", llt), scorefun = tern::score_occurrences, na.pos = "last")
       },
       env = list(llt = llt)
     )
@@ -409,7 +409,7 @@ tm_t_smq <- function(label,
                      total_label = default_total_label(),
                      sort_criteria = c("freq_desc", "alpha"),
                      drop_arm_levels = TRUE,
-                     na_level = default_na_str(),
+                     na_level = tern::default_na_str(),
                      smq_varlabel = "Standardized MedDRA Query",
                      baskets,
                      scopes,
@@ -485,9 +485,10 @@ ui_t_smq <- function(id, ...) {
     output = teal.widgets::white_small_well(teal.widgets::table_with_settings_ui(ns("table"))),
     encoding = tags$div(
       ### Reporter
-      teal.reporter::simple_reporter_ui(ns("simple_reporter")),
+      teal.reporter::add_card_button_ui(ns("add_reporter"), label = "Add Report Card"),
+      tags$br(), tags$br(),
       ###
-      tags$label("Encodings", class = "text-primary"),
+      tags$label("Encodings", class = "text-primary"), tags$br(),
       teal.transform::datanames_input(a[c(
         "arm_var", "baskets", "llt", "id_var", "scopes"
       )]),
@@ -511,9 +512,10 @@ ui_t_smq <- function(id, ...) {
         is_single_dataset = is_single_dataset_value
       ),
       ui_decorate_teal_data(ns("decorator"), decorators = select_decorators(a$decorators, "table")),
-      teal.widgets::panel_group(
-        teal.widgets::panel_item(
-          "Additional Variables Info",
+      bslib::accordion(
+        open = TRUE,
+        bslib::accordion_panel(
+          title = "Additional Variables Info",
           checkboxInput(
             ns(
               "drop_arm_levels"
@@ -715,7 +717,7 @@ srv_t_smq <- function(id,
         card$append_src(source_code_r())
         card
       }
-      teal.reporter::simple_reporter_srv("simple_reporter", reporter = reporter, card_fun = card_fun)
+      teal.reporter::add_card_button_srv("add_reporter", reporter = reporter, card_fun = card_fun)
     }
     ###
   })
