@@ -21,14 +21,14 @@ control_tte <- function(
       ties = "efron",
       conf_level = 0.95
     ),
-    surv_timepoint = control_surv_timepoint(
+    surv_timepoint = tern::control_surv_timepoint(
       conf_level = 0.95,
       conf_type = c("plain", "none", "log", "log-log")
     )) {
   list(
-    surv_time = do.call("control_surv_time", surv_time),
-    coxph = do.call("control_coxph", coxph),
-    surv_timepoint = do.call("control_surv_timepoint", surv_timepoint)
+    surv_time = do.call("control_surv_time", surv_time, envir = getNamespace("tern")),
+    coxph = do.call("control_coxph", coxph, envir = getNamespace("tern")),
+    surv_timepoint = do.call("control_surv_timepoint", surv_timepoint, envir = getNamespace("tern"))
   )
 }
 
@@ -63,7 +63,7 @@ template_tte <- function(dataname = "ANL",
                          control = control_tte(),
                          add_total = FALSE,
                          total_label = default_total_label(),
-                         na_level = default_na_str(),
+                         na_level = tern::default_na_str(),
                          basic_table_args = teal.widgets::basic_table_args()) {
   checkmate::assert_string(dataname)
   checkmate::assert_string(parentname)
@@ -118,7 +118,7 @@ template_tte <- function(dataname = "ANL",
   data_list <- add_expr(
     data_list,
     substitute(
-      expr = df_explicit_na(na_level = na_str),
+      expr = tern::df_explicit_na(na_level = na_str),
       env = list(na_str = na_level)
     )
   )
@@ -126,7 +126,7 @@ template_tte <- function(dataname = "ANL",
   y$data <- substitute(
     expr = {
       anl <- data_pipe
-      parentname <- arm_preparation %>% df_explicit_na(na_level = na_str)
+      parentname <- arm_preparation %>% tern::df_explicit_na(na_level = na_str)
     },
     env = list(
       data_pipe = pipe_expr(data_list),
@@ -208,7 +208,7 @@ template_tte <- function(dataname = "ANL",
   layout_list <- add_expr(
     layout_list,
     substitute(
-      expr = analyze_vars(
+      expr = tern::analyze_vars(
         "is_event",
         .stats = "count_fraction",
         .labels = c(count_fraction = "Patients with event (%)"),
@@ -217,14 +217,14 @@ template_tte <- function(dataname = "ANL",
         rtables::split_rows_by(
           "EVNT1",
           split_label = "Earliest contributing event",
-          split_fun = keep_split_levels("Patients with event (%)"),
+          split_fun = rtables::keep_split_levels("Patients with event (%)"),
           label_pos = "visible",
           child_labels = "hidden",
           indent_mod = 1L,
         ) %>%
-        rtables::split_rows_by(event_desc_var, split_fun = drop_split_levels) %>%
+        rtables::split_rows_by(event_desc_var, split_fun = rtables::drop_split_levels) %>%
         rtables::summarize_row_groups(format = "xx", na_str = na_str) %>%
-        analyze_vars(
+        tern::analyze_vars(
           "is_not_event",
           .stats = "count_fraction",
           .labels = c(count_fraction = "Patients without event (%)"),
@@ -242,7 +242,7 @@ template_tte <- function(dataname = "ANL",
   layout_list <- add_expr(
     layout_list,
     substitute(
-      expr = surv_time(
+      expr = tern::surv_time(
         vars = aval_var,
         var_labels = paste0("Time to Event (", as.character(anl$time_unit_var[1]), ")"),
         is_event = "is_event",
@@ -267,7 +267,7 @@ template_tte <- function(dataname = "ANL",
     layout_list <- add_expr(
       layout_list,
       substitute(
-        expr = coxph_pairwise(
+        expr = tern::coxph_pairwise(
           vars = aval_var,
           is_event = "is_event",
           var_labels = c("Unstratified Analysis"),
@@ -292,12 +292,12 @@ template_tte <- function(dataname = "ANL",
     layout_list <- add_expr(
       layout_list,
       substitute(
-        expr = coxph_pairwise(
+        expr = tern::coxph_pairwise(
           vars = aval_var,
           is_event = "is_event",
           var_labels = paste0("Stratified By: ", paste(strata_var, collapse = ", ")),
           strata = strata_var,
-          control = control_coxph(
+          control = tern::control_coxph(
             pval_method = pval_method,
             ties = ties,
             conf_level = conf_level
@@ -330,13 +330,13 @@ template_tte <- function(dataname = "ANL",
     layout_list <- add_expr(
       layout_list,
       substitute(
-        expr = surv_timepoint(
+        expr = tern::surv_timepoint(
           vars = aval_var,
           var_labels = as.character(anl$time_unit_var[1]),
           is_event = "is_event",
           time_point = time_points,
           method = method,
-          control = control_surv_timepoint(
+          control = tern::control_surv_timepoint(
             conf_level = conf_level,
             conf_type = conf_type
           ),
@@ -514,7 +514,7 @@ tm_t_tte <- function(label,
                      event_desc_var = teal.transform::choices_selected("EVNTDESC", "EVNTDESC", fixed = TRUE),
                      add_total = FALSE,
                      total_label = default_total_label(),
-                     na_level = default_na_str(),
+                     na_level = tern::default_na_str(),
                      pre_output = NULL,
                      post_output = NULL,
                      basic_table_args = teal.widgets::basic_table_args(),
@@ -595,9 +595,10 @@ ui_t_tte <- function(id, ...) {
     output = teal.widgets::white_small_well(teal.widgets::table_with_settings_ui(ns("table"))),
     encoding = tags$div(
       ### Reporter
-      teal.reporter::simple_reporter_ui(ns("simple_reporter")),
+      teal.reporter::add_card_button_ui(ns("add_reporter"), label = "Add Report Card"),
+      tags$br(), tags$br(),
       ###
-      tags$label("Encodings", class = "text-primary"),
+      tags$label("Encodings", class = "text-primary"), tags$br(),
       teal.transform::datanames_input(
         a[c("arm_var", "paramcd", "aval_var", "cnsr_var", "strata_var", "event_desc_var")]
       ),
@@ -627,11 +628,10 @@ ui_t_tte <- function(id, ...) {
       ),
       tags$div(
         class = "arm-comp-box",
-        tags$label("Compare Treatments"),
-        shinyWidgets::switchInput(
-          inputId = ns("compare_arms"),
-          value = !is.null(a$arm_ref_comp),
-          size = "mini"
+        bslib::input_switch(
+          id = ns("compare_arms"),
+          label = "Compare Treatments",
+          value = !is.null(a$arm_ref_comp)
         ),
         conditionalPanel(
           condition = paste0("input['", ns("compare_arms"), "']"),
@@ -671,7 +671,7 @@ ui_t_tte <- function(id, ...) {
       ),
       conditionalPanel(
         condition = paste0("input['", ns("compare_arms"), "']"),
-        teal.widgets::panel_item(
+        bslib::accordion_panel(
           "Comparison settings",
           radioButtons(
             ns("pval_method_coxph"),
@@ -716,8 +716,9 @@ ui_t_tte <- function(id, ...) {
           )
         )
       ),
-      teal.widgets::panel_item(
+      bslib::accordion_panel(
         "Additional table settings",
+        open = TRUE,
         teal.widgets::optionalSelectInput(
           inputId = ns("conf_level_survfit"),
           label = HTML(
@@ -954,7 +955,7 @@ srv_t_tte <- function(id,
         time_unit_var = as.vector(anl_m$columns_source$time_unit_var),
         event_desc_var = as.vector(anl_m$columns_source$event_desc_var),
         control = control_tte(
-          coxph = control_coxph(
+          coxph = tern::control_coxph(
             pval_method = input$pval_method_coxph,
             ties = input$ties_coxph,
             conf_level = as.numeric(input$conf_level_coxph)
@@ -964,7 +965,7 @@ srv_t_tte <- function(id,
             conf_type = input$conf_type_survfit,
             quantiles = input$probs_survfit
           ),
-          surv_timepoint = control_surv_timepoint(
+          surv_timepoint = tern::control_surv_timepoint(
             conf_level = as.numeric(input$conf_level_survfit),
             conf_type = input$conf_type_survfit
           )
@@ -1015,7 +1016,7 @@ srv_t_tte <- function(id,
         card$append_src(source_code_r())
         card
       }
-      teal.reporter::simple_reporter_srv("simple_reporter", reporter = reporter, card_fun = card_fun)
+      teal.reporter::add_card_button_srv("add_reporter", reporter = reporter, card_fun = card_fun)
     }
     ###
   })
