@@ -79,6 +79,7 @@ output_functions <- c(
 testthat::test_that(
   "e2e - tm_a_mmrm: Module initializes in teal without errors and displays a message to click 'Fit Model'.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
 
     app_driver <- app_driver_tm_a_mmrm(FALSE)
@@ -98,10 +99,11 @@ testthat::test_that(
   visit_var, cov_var, arm_var, buckets, combine_comp_arms, id_var, cor_struct,
   weights_emmeans, conf_level, method, parallel and output_function.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_a_mmrm(FALSE)
 
-    testthat::expect_equal(app_driver$get_text("#teal-teal_modules-active_tab > li.active > a"), "MMRM")
+    testthat::expect_equal(app_driver$get_text("#teal-teal_modules-active_tab .active"), "MMRM")
 
     testthat::expect_equal(app_driver$get_active_module_input("aval_var-dataset_ADQS_singleextract-select"), "AVAL")
 
@@ -145,6 +147,7 @@ testthat::test_that(
 )
 
 testthat::test_that("e2e - tm_a_mmrm: Click on fit model shows table for default selection.", {
+  testthat::skip("chromium")
   skip_if_too_deep(5)
   app_driver <- app_driver_tm_a_mmrm()
   app_driver$expect_no_validation_error()
@@ -161,10 +164,12 @@ testthat::test_that(
   "e2e - tm_a_mmrm: Function t_mmrm_lsmeans selection shows output settings; changing
   settings throws no validation errors and verify visibility of generated tables.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_a_mmrm()
 
     app_driver$click(selector = app_driver$active_module_element("button_start"))
+    app_driver$wait_for_idle()
     app_driver$expect_no_validation_error()
 
     app_driver$set_active_module_input("output_function", "t_mmrm_lsmeans", wait_ = FALSE)
@@ -181,10 +186,12 @@ testthat::test_that(
   "e2e - tm_a_mmrm: Function g_mmrm_lsmeans selection shows output settings; changing
   settings throws no validation errors and verify visibility of generated plots.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_a_mmrm()
 
     app_driver$click(selector = app_driver$active_module_element("button_start"))
+    app_driver$wait_for_idle()
     app_driver$expect_no_validation_error()
 
     app_driver$set_active_module_input("output_function", "g_mmrm_lsmeans", wait_ = FALSE)
@@ -222,10 +229,12 @@ testthat::test_that(
   "e2e - tm_a_mmrm: Function g_mmrm_diagnostic selection shows output settings; changing
   settings throws no validation errors and verify visibility of generated plots.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_a_mmrm()
 
     app_driver$click(selector = app_driver$active_module_element("button_start"))
+    app_driver$wait_for_idle()
     app_driver$expect_no_validation_error()
 
     app_driver$set_active_module_input("output_function", "g_mmrm_diagnostic", wait_ = FALSE)
@@ -252,6 +261,7 @@ for (func in output_functions) {
       func
     ),
     {
+      testthat::skip("chromium")
       skip_if_too_deep(5)
       app_driver <- app_driver_tm_a_mmrm()
       # Set initial output function
@@ -287,6 +297,7 @@ for (func in output_functions) {
       func
     ),
     {
+      testthat::skip("chromium")
       skip_if_too_deep(5)
       app_driver <- app_driver_tm_a_mmrm()
       # Set initial output function
@@ -322,6 +333,7 @@ for (func in output_functions) {
       func
     ),
     {
+      testthat::skip("chromium")
       skip_if_too_deep(5)
       app_driver <- app_driver_tm_a_mmrm()
       # Set initial output function
@@ -357,6 +369,7 @@ for (func in output_functions) {
       func
     ),
     {
+      testthat::skip("chromium")
       skip_if_too_deep(5)
       app_driver <- app_driver_tm_a_mmrm()
       # Set initial output function
@@ -392,6 +405,7 @@ for (func in output_functions) {
       func
     ),
     {
+      testthat::skip("chromium")
       skip_if_too_deep(5)
       app_driver <- app_driver_tm_a_mmrm()
       # Set initial output function
@@ -427,6 +441,7 @@ for (func in output_functions) {
       func
     ),
     {
+      testthat::skip("chromium")
       skip_if_too_deep(5)
       app_driver <- app_driver_tm_a_mmrm()
       # Set initial output function
@@ -494,6 +509,7 @@ for (func in output_functions) {
       func
     ),
     {
+      testthat::skip("chromium")
       skip_if_too_deep(5)
       app_driver <- app_driver_tm_a_mmrm()
       # Set initial output function
@@ -515,6 +531,7 @@ for (func in output_functions) {
 
         app_driver$set_active_module_input(input_name, input_list[[input_name]])
         app_driver$click(selector = app_driver$active_module_element("button_start"))
+        app_driver$wait_for_idle()
         app_driver$expect_no_validation_error()
 
         # Check output based on function type (plot or table)
