@@ -87,6 +87,7 @@ app_driver_tm_g_pp_patient_timeline <- function() { # nolint object_length.
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Module initializes in teal without errors and produces plot output.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     app_driver$expect_no_shiny_error()
@@ -105,11 +106,12 @@ testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Starts with specified label, patient_id, cmdecod, aeterm, aetime_start,
   aetime_end, dstime_start, dstime_end, aerelday_start, aerelday_end, dsrelday_start, dsrelday_en.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
 
     testthat::expect_equal(
-      app_driver$get_text("#teal-teal_modules-active_tab > li.active > a"),
+      app_driver$get_text("#teal-teal_modules-active_tab .active > a"),
       "Patient Timeline"
     )
     testthat::expect_equal(
@@ -170,6 +172,7 @@ testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Encodings aerelday_start, aerelday_end, dsrelday_start, dsrelday_end
   are shown only when relday_x_axis is checked.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
 
@@ -201,6 +204,7 @@ testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Encodings aetime_start, aetime_end, dstime_start, dstime_end
   are shown only when relday_x_axis is unchecked.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
 
@@ -231,6 +235,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Selecting patient_id changes plot and doesn't throw validation errors.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     plot_before <- app_driver$get_active_module_plot_output("patient_timeline_plot")
@@ -247,6 +252,7 @@ testthat::test_that(
 )
 
 testthat::test_that("e2e - tm_g_pp_patient_timeline: Deselecting patient_id column throws validation error.", {
+  testthat::skip("chromium")
   skip_if_too_deep(5)
   app_driver <- app_driver_tm_g_pp_patient_timeline()
   app_driver$set_active_module_input("patient_id", NULL)
@@ -262,6 +268,7 @@ testthat::test_that("e2e - tm_g_pp_patient_timeline: Deselecting patient_id colu
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Selecting cmdecod changes plot and doesn't throw validation errors.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     plot_before <- app_driver$get_active_module_plot_output("patient_timeline_plot")
@@ -280,6 +287,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Deselecting cmdecod changes plot and doesn't throw validation error.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     plot_before <- app_driver$get_active_module_plot_output("patient_timeline_plot")
@@ -293,6 +301,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Selecting aeterm changes plot and doesn't throw validation errors.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     plot_before <- app_driver$get_active_module_plot_output("patient_timeline_plot")
@@ -311,6 +320,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Deselecting aeterm changes plot and doesn't throw validation error.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     plot_before <- app_driver$get_active_module_plot_output("patient_timeline_plot")
@@ -324,6 +334,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Selecting aetime_start changes plot and doesn't throw validation errors.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     app_driver$set_active_module_input("relday_x_axis", FALSE)
@@ -343,6 +354,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Deselecting aetime_start throws validation error.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     app_driver$set_active_module_input("relday_x_axis", FALSE)
@@ -360,6 +372,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Selecting aetime_end changes plot and doesn't throw validation errors.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     app_driver$set_active_module_input("relday_x_axis", FALSE)
@@ -379,6 +392,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Deselecting aetime_end throws validation error.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     app_driver$set_active_module_input("relday_x_axis", FALSE)
@@ -396,6 +410,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Selecting aerelday_start changes plot and doesn't throw validation errors.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     plot_before <- app_driver$get_active_module_plot_output("patient_timeline_plot")
@@ -414,6 +429,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Deselecting aerelday_start throws validation error.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     app_driver$set_active_module_input("aerelday_start-dataset_ADAE_singleextract-select", NULL)
@@ -430,6 +446,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Selecting aerelday_end changes plot and doesn't throw validation errors.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     plot_before <- app_driver$get_active_module_plot_output("patient_timeline_plot")
@@ -448,6 +465,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Deselecting aerelday_end throws validation error.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     app_driver$set_active_module_input("aerelday_end-dataset_ADAE_singleextract-select", NULL)
@@ -464,6 +482,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Selecting dstime_start changes plot and doesn't throw validation errors.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     app_driver$set_active_module_input("relday_x_axis", FALSE)
@@ -483,6 +502,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Deselecting dstime_start throws validation error.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     app_driver$set_active_module_input("relday_x_axis", FALSE)
@@ -500,6 +520,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Selecting dstime_end changes plot and doesn't throw validation errors.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     app_driver$set_active_module_input("relday_x_axis", FALSE)
@@ -519,6 +540,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Deselecting dstime_end throws validation error.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     app_driver$set_active_module_input("relday_x_axis", FALSE)
@@ -536,6 +558,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Selecting dsrelday_start changes plot and doesn't throw validation errors.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     plot_before <- app_driver$get_active_module_plot_output("patient_timeline_plot")
@@ -554,6 +577,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Deselecting dsrelday_start throws validation error.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     app_driver$set_active_module_input("dsrelday_start-dataset_ADCM_singleextract-select", NULL)
@@ -570,6 +594,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Selecting dsrelday_end changes plot and doesn't throw validation errors.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     plot_before <- app_driver$get_active_module_plot_output("patient_timeline_plot")
@@ -588,6 +613,7 @@ testthat::test_that(
 testthat::test_that(
   "e2e - tm_g_pp_patient_timeline: Deselecting dsrelday_end throws validation error.",
   {
+    testthat::skip("chromium")
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_g_pp_patient_timeline()
     app_driver$set_active_module_input("dsrelday_end-dataset_ADCM_singleextract-select", NULL)
